@@ -1,12 +1,12 @@
-from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
-from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
+from bxcommon.messages.bloxroute.v12.message_converter_factory_v12 import message_converter_factory_v12
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
 from bxcommon.messages.versioning.no_changes_message_converter import no_changes_message_converter
 
 
 class _MessageConverterFactoryV11(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
-        BloxrouteMessageType.PONG: pong_message_converter_v13
+        # pylint: disable=protected-access
+        **message_converter_factory_v12._MESSAGE_CONVERTER_MAPPING,
     }
 
     def get_message_converter(self, msg_type):
