@@ -1,5 +1,5 @@
 from bxcommon.messages.bloxroute.bloxroute_message_type import BloxrouteMessageType
-from bxcommon.messages.bloxroute.v13.pong_message_converter_v13 import pong_message_converter_v13
+from bxcommon.messages.bloxroute.v10.message_converter_factory_v10 import message_converter_factory_v10
 from bxcommon.messages.bloxroute.v9.bdn_performance_stats_message_converter_v9 \
     import bdn_performance_stats_message_converter_v9
 from bxcommon.messages.versioning.abstract_version_converter_factory import AbstractMessageConverterFactory
@@ -8,8 +8,9 @@ from bxcommon.messages.versioning.no_changes_message_converter import no_changes
 
 class _MessageConverterFactoryV9(AbstractMessageConverterFactory):
     _MESSAGE_CONVERTER_MAPPING = {
+        # pylint: disable=protected-access
+        **message_converter_factory_v10._MESSAGE_CONVERTER_MAPPING,
         BloxrouteMessageType.BDN_PERFORMANCE_STATS: bdn_performance_stats_message_converter_v9,
-        BloxrouteMessageType.PONG: pong_message_converter_v13
     }
 
     def get_message_converter(self, msg_type):
