@@ -48,11 +48,22 @@ class OutboundPeerModel:
 
         return None
 
+    def get_region(self) -> Optional[str]:
+        if constants.NODE_REGION_ATTRIBUTE_NAME in self.attributes:
+            return self.attributes[constants.NODE_REGION_ATTRIBUTE_NAME]
+
+        return None
+
     def is_transaction_streamer(self) -> bool:
         return self.attributes.get(
             constants.TRANSACTION_STREAMER_ATTRIBUTE_NAME, False
         )
 
+    def using_private_ip(self) -> bool:
+        return self.attributes.get(
+            constants.PRIVATE_IP_ATTRIBUTE_NAME, False
+        )
+
     def __str__(self):
         return (
             f"({self.node_type}, {self.ip}, {self.port}, {self.node_id}, "
