@@ -8,7 +8,7 @@ from typing import Iterable, Optional, Type, Callable, List
 import uvloop
 
 from bxcommon.connections.abstract_node import AbstractNode
-from bxcommon.exceptions import TerminationError, HighMemoryError
+from bxcommon.exceptions import TerminationError, HighMemoryError, FeedSubscriptionTimeoutError
 from bxcommon.models.node_type import NodeType
 from bxcommon.network.node_event_loop import NodeEventLoop
 from bxcommon.services import sdn_http_service
@@ -117,6 +117,14 @@ def run_node(
         _close_handles()
         python = sys.executable
         os.execl(python, python, *sys.argv)
+    except FeedSubscriptionTimeoutError:
+        logger.info(
+            "Restarting node due to feed subscription timeout, "
+            "node is probably not synced with the blockchain node."
+        )
+        _close_handles()
+        python = sys.executable
+        os.execl(python, python, *sys.argv)
     except Exception as e:  # pylint: disable=broad-except
         logger.fatal("Unhandled exception {} raised, terminating!", e)
 
