@@ -139,6 +139,10 @@ def submit_peer_connection_event(
     )
 
 
+def submit_gateway_switching_relays_event(node_id: str) -> None:
+    submit_node_event(NodeEventModel(node_id=node_id, event_type=NodeEventType.SWITCHING_RELAYS))
+
+
 def submit_gateway_inbound_connection(node_id: str, peer_id: str) -> None:
     http_service.post_json(SdnRoutes.gateway_inbound_connection.format(node_id), peer_id)
 
@@ -151,10 +155,6 @@ def submit_tx_not_synced_event(node_id: str) -> None:
     submit_node_event(NodeEventModel(node_id=node_id, event_type=NodeEventType.TX_SERVICE_NOT_SYNCED))
 
 
-def submit_notify_online_event(node_id: str) -> None:
-    submit_node_event(NodeEventModel(node_id=node_id, event_type=NodeEventType.NOTIFY_ONLINE))
-
-
 def submit_notify_offline_event(node_id: str) -> None:
     submit_node_event(NodeEventModel(node_id=node_id, event_type=NodeEventType.NOTIFY_OFFLINE))
 
