@@ -106,7 +106,13 @@ class AlarmQueue:
         self.lock = RLock()
 
     def register_alarm(
-        self, fire_delay: float, fn: Callable, *args, alarm_name: Optional[str] = None, **kwargs
+        self,
+        fire_delay: float,
+        fn: Callable,
+        *args,
+        alarm_name: Optional[str] = None,
+        fire_immediately: bool = False,
+        **kwargs
     ) -> AlarmId:
         """
         Schedules an alarm to be fired in `fire_delay` seconds. Function must return a positive integer
@@ -114,6 +120,7 @@ class AlarmQueue:
         :param fire_delay: delay in seconds before firing alarm
         :param fn: function to be fired on delay
         :param alarm_name: optional label for alarm
+        :param fire_immediately: fires alarm immediately if delay is 0
         :param args: function arguments
         :return: (fire time, unique count, alarm function)
         """
@@ -129,6 +136,11 @@ class AlarmQueue:
 
         alarm = Alarm(fn, time.time() + fire_delay, *args, name=alarm_name, **kwargs)
         alarm_id = AlarmId(time.time() + fire_delay, self.uniq_count, alarm)
+
+        if fire_immediately and fire_delay == 0:
+            alarm.fire()
+            return alarm_id
+
         with self.lock:
             heappush(self.alarms, alarm_id)
             self.uniq_count += 1
@@ -150,6 +162,7 @@ class AlarmQueue:
         :param slop: range during which only once instance of this function may be fire
         :param fn: function to be fired
         :param args: function arguments
+        :param alarm_name: name of alarm for logging
         """
         try:
             hash(fn)
@@ -214,6 +227,8 @@ class AlarmQueue:
                     # pylint: disable=broad-except
                     except Exception as e:
                         logger.exception("Alarm {} could not fire and failed with exception: {}", alarm, e)
+                        if alarm.fn in self.approx_alarms_scheduled:
+                            self._pop_and_cleanup_approx_alarm(alarm_id)
                     else:
                         performance_utils.log_operation_duration(
                             alarm_troubleshooting_logger,
@@ -229,14 +244,7 @@ class AlarmQueue:
                             heappush(self.alarms, alarm_id)
                         # Delete alarm from approx_alarms_scheduled if applicable
                         elif alarm.fn in self.approx_alarms_scheduled:
-                            alarm_heap = self.approx_alarms_scheduled[alarm.fn]
-
-                            # alarm that was just fired must be the first one in the list
-                            assert alarm_heap[0].count == alarm_id.count
-                            heappop(alarm_heap)
-
-                            if not alarm_heap:
-                                del self.approx_alarms_scheduled[alarm.fn]
+                            self._pop_and_cleanup_approx_alarm(alarm_id)
 
         performance_utils.log_operation_duration(
             alarm_troubleshooting_logger,
@@ -270,3 +278,13 @@ class AlarmQueue:
 
             time_to_alarm = self.alarms[0].fire_time - time.time()
             return time_to_alarm
+
+    def _pop_and_cleanup_approx_alarm(self, alarm_id: AlarmId) -> None:
+        alarm_heap = self.approx_alarms_scheduled[alarm_id.alarm.fn]
+
+        # alarm that was just fired must be the first one in the list
+        assert alarm_heap[0].count == alarm_id.count
+        heappop(alarm_heap)
+
+        if not alarm_heap:
+            del self.approx_alarms_scheduled[alarm_id.alarm.fn]
