@@ -6,4 +6,4 @@ class StatBlockType(Enum):
     COMPRESSED = "compressed"
 
     def __str__(self) -> str:
-        return self.value
+        return str(self.value)
