@@ -2,7 +2,7 @@ from typing import TYPE_CHECKING
 
 from bxcommon.messages.bloxroute.tx_message import TxMessage
 from bxcommon.network.abstract_socket_connection_protocol import AbstractSocketConnectionProtocol
-from bxcommon.utils.blockchain_utils.btc import btc_common_util
+from bxcommon.utils.blockchain_utils.btc import btc_common_utils
 from bxgateway.connections.abstract_relay_connection import AbstractRelayConnection
 from bxutils import logging
 from bxgateway import log_messages
@@ -20,7 +20,7 @@ class BtcRelayConnection(AbstractRelayConnection):
 
     def msg_tx(self, msg):
         if msg.tx_val() != TxMessage.EMPTY_TX_VAL:
-            hash_val = btc_common_util.get_txid(msg.tx_val())
+            hash_val = btc_common_utils.get_txid(msg.tx_val())
 
             if hash_val != msg.tx_hash():
                 self.log_error(log_messages.MALFORMED_TX_FROM_RELAY, hash_val, msg.tx_hash())
