@@ -13,6 +13,9 @@ class EthProtocolMessageType:
     GET_BLOCK_BODIES = 21
     BLOCK_BODIES = 22
     NEW_BLOCK = 23
+    NEW_POOLED_TRANSACTION_HASHES = 24
+    GET_POOLED_TRANSACTIONS = 25
+    POOLED_TRANSACTIONS = 26
     GET_NODE_DATA = 29
     NODE_DATA = 30
     GET_RECEIPTS = 31
