@@ -1,7 +1,6 @@
 import struct
 
-import rlp
-
+import blxr_rlp as rlp
 from bxcommon.utils.blockchain_utils.eth import crypto_utils, eth_common_constants
 
 
